@@ -1,4 +1,18 @@
 
+#####################################################################
+#
+# s_net.py
+#
+# Project   : OMNICLIENT
+# Author(s) : Zafar Iqbal < zaf@sparc.space >
+# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
+#
+# All rights reserved. No warranty, explicit or implicit, provided.
+# SPARC PC is and remains the owner of all titles, rights
+# and interests in the Software.
+#
+#####################################################################
+
 import os
 import json
 import time
@@ -472,7 +486,13 @@ def get_request_response( request_headers , payload = "" , zendpoint = "omniclie
     else:
         endpoint_timeout = int( endpoint_timeout )
 
-    endpoint_url = s_config.get_key( "endpoint/url" ) + zendpoint + ".html"
+
+    endpoint_url = s_config.get_key( "endpoint/url" ) 
+    if(not endpoint_url):
+        s_log.write("false endpoint_url")
+        return(False)
+
+    endpoint_url = endpoint_url + zendpoint + ".html"
     #s_log.write(endpoint_url)
 
     #####################################################################
